#ifndef AKENTI_CERT_GENERATOR_HPP
#define AKENTI_CERT_GENERATOR_HPP

#include "AkentiCertificate.hpp"

namespace Akenti {

/**
  * This class provides functionality will be used by all the akenti generators.
  * 
  * @see AkentiCertificate
  * @see AkentiCertificateImpl
  * @see AkentiPrincipal
  * @see UtcTime
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  **/

class AkentiCertGenerator {

public:

  /**
    * Deletes this object
    */
  ~AkentiCertGenerator();

 /**
   * Sets the versionNumber to the Akenti Certificate being generated. 
   *
   * @param versionNumber is set to the generated certificate
   */
  void setVersionNumber(int version);

 /**
   * Sets the unique identification string representing the 
   * Akenti Certificate being generated.
   *
   * @param id is set to  the generated certificate
   **/
  void setUniqueID(const string& id);

 /**
   * Sets the issuer of the Akenti Certificate being generated
   * in the form of <i> AkentiPrincipal </i>
   *
   * @param issuer is set to the generated certificate
   * @see AkentiIssuer
   */
  void setIssuer(const AkentiIssuer& issuer);

  /**
    * Sets the Greenwich Mean Time (GMT) of the starting validity date of the
    * certificate being generated
    *
    * @param notBefore is set to the genetated certificate
    * @see UtcTime
    **/
  void setNotBefore(const UtcTime& notBefore);

  /**
    * Sets the Greenwich Mean Time (GMT) of the ending validity date of the
    * certificate being generated
    *
    * @param notAfter is set to the generated certificate
    * @see UtcTime
    **/
  void setNotAfter(const UtcTime& notAfter);

  /**
    * Signs the certificate being generated with specified privateKey and 
    * signatureAlg.
    *
    * @param privateKey
    * @param signatureAlg
    * @see PrivateKey
    **/
  void sign(const PrivateKey &privateKey, const string& signatureAlg);

  /**
    * Generates the certificate.
    **/
  const AkentiCertificate& generate();
 
protected:

  /**
    * Constructs a AkentiCertGenerator object with a AkentiCertificateImpl 
    * object.
    */ 
  AkentiCertGenerator(AkentiCertificateImpl *impl);

 /**
   * Sets the type of Akenti Certificate that this object refers to
   *
   * @param type is set to this certificate
   */
  AkentiCertificate akentiCert;

};

} // end of name space

#endif
