#ifndef AKENTI_X509_CERTIFICATE_IMPL_HPP
#define AKENTI_X509_CERTIFICATE_IMPL_HPP

#include "AkentiCertificateImpl.hpp"
#include "Certificate.hpp"
#include "URL.hpp"
#include "PublicKey.hpp"

namespace Akenti {
/**
  * This is is used internally by the engine. It adpats the standard
  * x509 certificate to the akenti certificates.
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */

class AkentiX509CertificateImpl : public AkentiCertificateImpl {

public:

  /**
    * Constructs this object.
    */
  AkentiX509CertificateImpl();

  /**
    * Constructs this object given a standard x509 certificate.
    */
  AkentiX509CertificateImpl(const Certificate& cert);

  /**
    * Destructor.
    */
  ~AkentiX509CertificateImpl();

  /**
    */
  const AkentiPrincipal& getPrincipal() const;

  /**
    */
  const PublicKey& getSubjectPublicKey() const;

  /**
    */ 
  const URL& getRevocationURL() const;

  /**
    */
  int getSerialNumber() const;

  /**
    */
  string getSignable() const;

  /**
    */
  string getHashString() const;

protected:

  /**
    * Writes out a DER encoded version of the wrapped X509 certificate,
    */
  void writeObject(AkentiOutputStream& drain) const;

  /**
    * Reads a DER encoded X509 certificate from the input stream.
    */
  void readObject(AkentiInputStream& source);

  /**
    */
  AkentiX509CertificateImpl* newInstance() const;

  /**
    */
  void doWrite(AkentiOutputStream& drain) const {
  }

  /**
    */
  void doRead(AkentiInputStream& source) {
  }

  /**
    */
  void doParamString(ostream& os) const;

  /**
    */ 
  void doToText(int indentAmt, ostream& os) const; 

  /**
    */
  void doToLogString(ostream& os) const;

private:

  friend class AkentiX509CertGenerator;

  void init();

  void defaultInit();

  void sign(const string& signatureAlg, const PrivateKey &privateKey);

  string signable;

  AkentiPrincipal principal;

  int serialNumber;

  URL revocationURL;
  
  PublicKey subjectPublicKey;

  Certificate cert;

};

} // end of name space

#endif
