#ifndef AKENTI_CHECK_ACCESS_REQUEST_HPP
#define AKENTI_CHECK_ACCESS_REQUEST_HPP

#include <vector>
#include <map>
#include <set>
#include "AkentiRequest.hpp"
#include "AkentiPrincipal.hpp"
#include "Certificate.hpp"

using std::vector;
using std::map;

using namespace std;

namespace Akenti {


/**
  * Holds the content of a CheckAccessRequest.                    <BR>
  * 
  * This request is used to  determine the privileges of a user 
  * for a resource.                                               <BR>
  *
  * @see AkentiRequest
  */
class CheckAccessRequest : public AkentiRequest {
 
public:

  /**
    * Constructor
    */
  CheckAccessRequest();

  /**
    * Sets the name of the resource.
    */
  void setResource(const string& resource);
 
  /**
    * Returns the name of the resource.
    */
  const string& getResource() const;

  /**
    * Sets the principal accessing the resource.
    * request.
    */
  void setAkentiPrincipal(const AkentiPrincipal& ap);

  /**
    * Returns true if this <i>CheckAccessRequest</i> contains 
    * a principal.
    */
  bool containsAkentiPrincipal() const;

  /**
    * Returns the AkentiPrincipal that is in the message.
    *
    * @see containsAkentiPrincipal
    */
  const AkentiPrincipal& getAkentiPrincipal() const; 

  /**
    * Returns true if this <i>CheckAccessRequest</i> contains 
    * an X509 chain.
    */
  bool containsX509Chain() const;

  /**
    * Sets the X509 chain of the principal accessing the resource.
    */
  void setX509Chain(const vector<Certificate>& certs);

  /**
    * Returns the X509 chain of the principal accessing the resource.
    *
    * @see containsX509Chain()
    */
  const vector<Certificate>& getX509Chain() const;

  /** 
    * Set DesiredActions vector 
    */
  void setDesiredActions (const set <string>& DesiredActionsVec);

  /** 
    * Returns the vector of desired actions
    */
  const set <string>& getDesiredActions() const;

  /**
    * Returns true if desired actions is a non Null vector, else returns
    * false
    */

  bool containsDesiredActions() const;

  /** 
    * Set RestrictedAttributes map
    */

  void setRestrictedAttributes (const multimap<string,string>& mapping);

  /** 
    * Returns the map of Restricted Attributes
    */

  const multimap<string, string>& getRestrictedAttributes() const;

  /**
    * Returns true if restricted attributes is a non Null map, else returns
    * false
    */

  bool containsRestrictedAttributes() const;

  /** 
    * Set this flag to true if you want a detailed response 
    */

  void  setDetailed (bool detailFlag);

  /**
    * Return flag that says if you wanted detailed output.
    */

  bool getDetailed () const;

private:

  friend class AkentiRequest;
  friend class AkentiRequestResponseImplFactory;
  class CheckAccessRequestImpl;
  static AkentiRequestImpl* getRequestImpl();
  typedef CheckAccessRequestImpl* ImplType;
};

}

#endif
