#ifndef AKENTI_CHECK_ACCESS_RESPONSE_HPP
#define AKENTI_CHECK_ACCESS_RESPONSE_HPP

#include "AkentiResponse.hpp"
#include "CapabilityCertificate.hpp"
#include "PolicyInfo.hpp"
#include "AkentiCertificate.hpp"

namespace Akenti {

/**
  * Used to wrap the response to a <i>CheckAccessRequest</i>.
  *
  * @see AkentiResponse
  * @see CheckAccessRequest
  */
class CheckAccessResponse : public AkentiResponse {
 
public:

  /**
    * Constuctor.
    */
  CheckAccessResponse();

  /**
    * Sets the user's <i>CapabilityCertificate</i>.
    *
    * @see CapabilityCertificate
    */
  void setCapabilityCertificate(const CapabilityCertificate& cert);

  /**
    * Returns the user's <i>CapabilityCertificate</i>.
    *
    * @see CapabilityCertificate
    */
  const CapabilityCertificate& getCapabilityCertificate() const;

   /**
     * Sets the vector of <i>PolicyInfo</i> that contains a <i>Policy</i>
     * certificate, and its associated <i> Use Condition </i> certificates.
     */
  void setPolicyInfo (const vector <PolicyInfo>& pInfo);

  /**
    * Returns the vector of <i>PolicyInfo</i> objects
    *
    * @see PolicyInfo
    */
  const vector <PolicyInfo>& getPolicyInfo() const;
 
  /** 
    * Adds a PolicyInfo to the policyInfos vector 
    */
  void addPolicyInfo (const PolicyInfo & pInfo);
 
   /**
     * Sets the vector of <i>AkentiCertificate</i> that may contain 
     * <i>Attribute </i> certificates or X509 certificates.
     */
  void setAkentiCerts (const vector <AkentiCertificate>& aCerts);

  /**
    * Returns the vector of <i>AkentiCertificate</i> that may be 
    * <i>Attribute Certificates </i> or X509 Certificates.
    *
    */
  const vector <AkentiCertificate>& getAkentiCerts() const;

  /** 
    * Adds a certificate to the akentiCerts vector 
    */
  void addAkentiCert (const AkentiCertificate & cert);
 

private:

  friend class AkentiResponse;
  friend class AkentiRequestResponseImplFactory;
  static AkentiResponseImpl* getResponseImpl();
  class CheckAccessResponseImpl;
  typedef CheckAccessResponseImpl* ImplType;

};

}

#endif
