#ifndef AKENTI_DELETE_RESOURCE_REQUEST_HPP
#define AKENTI_DELETE_RESOURCE_REQUEST_HPP

#include "AkentiRequest.hpp"

namespace Akenti {

/**
  * Class to handle the arguments in a DeleteResourceRequest.
  * This is the message that is sent to an Akenti server to
  * delete a resource in the given location.
  * @see AkentiRequest
  */
class DeleteResourceRequest : public AkentiRequest {
 
public:

  /**
    * Constructor
    */
  DeleteResourceRequest();

  /**
    * Sets the name of the resource base to delete.
    * Used by the client making the request.
    */
  void setResource(const string& resource);
 
  /**
    * Extracts the name of the resource from the message structure.
    * Used by the Akenti server when reading a DeleteResource message.
    */
  const string& getResource() const;

private:

  friend class AkentiRequest;
  friend class AkentiRequestResponseImplFactory;
  static AkentiRequestImpl* getRequestImpl(); 
  class DeleteResourceRequestImpl;
  typedef DeleteResourceRequestImpl* ImplType; 

};

}

#endif
