#ifndef AK_URL_HANDLER_FACTORY_HPP
#define AK_URL_HANDLER_FACTORY_HPP

#include "ref_ptr.hpp"
#include "URLHandlerFactoryImpl.hpp"

/**
  * A <i>URLHandlerFactory<i> object is a <b>reference-count</b> pointer 
  * that wraps a <i>URLHandlerFactoryImpl</i>. 
  *
  * @see URLHandlerFactoryImpl 
  *
  * @version 1.1 00/11/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  **/

namespace Akenti {

class URLHandlerFactory : public ref_ptr<URLHandlerFactoryImpl> {

public:
  
  /**
    * Constructs this object.
    *
    * @param impl the URL Handler factory implemenation 
    *
    */
  URLHandlerFactory(URLHandlerFactoryImpl* impl = new URLHandlerFactoryImpl());
  
  /**
    * Destroys this object.
    */
  ~URLHandlerFactory();

  /**
    * Sets the URL Handler Factory to fac.
    *
    * @param fac the URL handler factory 
    */
  static void 
  setURLHandlerFactory(const URLHandlerFactory& fac);

  /**
    * Returns the URL handler factory object.
    *
    * @return the URL handler factory
    */
  static const URLHandlerFactory&
  getURLHandlerFactory();

private:

  static URLHandlerFactory fac;

};

} // end of namespace Akenti

#endif

