// SERVER SIDE TOOLS
namespace CheckAccess {
  /**
    * <big>CheckAccess (akenti CA)</big><br>
    *
    * Use this program to checks a user's access to a resource. 
    *
    * <pre>
    * -f arg            - akenti engine config file
    * -r arg            - resource
    * [-x arg]          - user's x509 certificate chain (PEM)
    * [-u arg -c arg]   - user's DN and user's CADN
    * [-R arg]*         - one or more specific action(s)
    * [-A arg -V arg]*  - one or more attribute/value pair
    * [-P]              - show all certificates used in making the decision
    * [-o arg]          - certificates' output file (defaults to stdout)
    * [-q]              - show concise output
    * [-v]              - verbose
    * [-h]              - prints this message
    * </pre>
    * 
    * <i>What can a user do?</i>
    * example: akenti CheckAccess -f conf.txt -r "R1/S1" -x userX509Cert
    *
    * <i>Can a user do read and write?></i> (Ignore other actions)
    * example: akenti CA -f conf.txt -r "R1" -x cert -R read -R write 
    *
    * <i>What can a user playing the role of a manager do?<i> (Ignore other roles)
    * example: akenti CA -f conf.txt -r "R3" -x cert -A role  -V manager 
    */
  int main(int, char**);
}

namespace CheckPolicy {
  /**
    * <big>CheckPolicy (akenti CP)</big><br>
    *
    * Use this program to check resource's policy.
    *
    * <pre>
    * -f arg   - akenti engine config file
    * -r arg   - resource
    * [-l arg] - level 1, 2, or 3
    *            where each level is as follows:
    *             1 - prints WORKED/FAILED only
    *             2 - prints all messages collected (this is the default level)
    *             3 - prints level 3 and all the certificates as well, same as -a option
    * [-a]     - use level 3
    * [-v]     - verbose
    * [-h]     - prints this message
    * </pre>
    *
    * <i>Check the policy of the resource named "R1"</i><br>
    * example: akenti CheckPolicy -f conf.txt -r "R1" 
    * <p>
    * <i>Request all information concerning the policy of the resource called "R20"</i><br>
    * example: akenti CP -f conf.txt -r "R20" -a  
    */
  int main(int, char**);
}

namespace ResourceBrowse {
  /**
    * <big>ResourceBrowse (akenti RB)</big><br>
    *
    * Use this program to browse a resource. Lists the
    * immediate descendants of a particular resource.
    * Do not supply a resource to list the root resources.
    *
    * <pre>
    * -f arg  - akenti engine config file
    * -r arg  - resource
    * [-v]    - verbose
    * [-h]    - prints this message
    * </pre>
    *
    * <i>List top level resources.</i><br>
    * example: akenti ResourceBrowse -f conf.txt 
    * <p>
    * <i>List immediate resources under R1/S1</i><br>
    * example: akenti RB -f conf.txt -r R1/S1
    */
  int main(int, char**);
}

namespace CreateResource {
  /**
    * <big>CreateResource (akenti CR)</big><br>
    *
    * Use this program to create a resource. Unless a policy file
    * is uploaded using the UploadPolCert command, the resource 
    * will inherit policy attributes from its parent resource.
    *
    * <pre>
    * -f arg  - akenti engine config file
    * -r arg  - resource
    * [-v]    - verbose
    * [-h]    - prints this message
    * </pre>
    *
    * <i>Create a resource called "S2" under the resource called "R1"</i><br>
    * example: akenti CR -f conf.txt -r "R1/S2"
    */
  int main(int, char**);
}

namespace DeleteResource {
  /**
    * <big>DeleteResource (akenti DR)</big><br>
    *
    * Use this program to delete a resource.
    *
    * <pre>
    * -f arg  - akenti engine config file
    * -r arg  - resource
    * [-v]    - verbose
    * [-h]    - prints this message
    * </pre>
    *
    * <i>Deletes a resource called "S2" under the resource called "R1"</i><br>
    * example: akenti DR -f conf.txt -r "R1/S2"
    */
  int main(int, char**);
}

namespace UploadPolicyCertificate {
  /**
    * <big>UploadPolCert (akenti UP)</big><br>
    *
    * Use this program to upload a policy certificate. 
    *
    * <pre>
    * -f arg  - akenti engine config file
    * -p arg  - policy certificate file
    * [-v]    - verbose
    * [-h]    - prints this message
    * </pre>
    *
    * <i>Upload the policy certificate called "polCert".
    * The policy certificate will indicate which resource
    * it modifies.</i><br>
    * example: akenti UP -f conf.txt -p polCert
    */
  int main(int, char**);
}

namespace DeletePolicyCertificate {
  /**
    * <big>DeletePolCert (akenti DP)</big><br>
    *
    * Use this program to delete a policy certificate. Note: it will
    * only delete a certificate if it is located in the resource 
    * specified. A resource may be controlled by a policy certificate
    * in an ancestor directory.
    *
    * <pre>
    * -f arg  - akenti engine config file
    * -r arg  - resource
    * [-v]    - verbose
    * [-h]    - prints this message
    * </pre>
    *
    * <i>Delete the policy certificate located at R2 if there is one.</i>
    * example: akenti DP -f conf.txt -r "R2" 
    */
  int main(int, char**);
}
 
namespace RemoteCheckAccess {
  /**
    * <big>RemoteCheckAccess (akenti RCA)</big><br>
    *
    * Use this program to check a user's access to a remote resource.
    *
    * <pre>
    * -F arg           - akenti client config file
    * -r arg           - resource
    * [-x arg]         - user's x509 certificate chain
    * [-u arg -c arg]  - user's DN and user's CADN
    * [-q]             - show concise output
    * [-v]             - verbose
    * [-h]             - prints this message
    * </pre>
    *
    * <i>What can a user do?</i>
    * example: akenti RemoteCheckAccess -F conf.txt -r "R1/S1" -x userX509Cert
    */
  int main(int, char**);
}

namespace RemoteCheckPolicy {
  /**
    * <big>RemoteCheckPolicy (akenti RCP)</big><br>
    * Use this program to check policy for a remote resource.
    *
    * <pre>
    * -F arg - akenti client config file
    * -r arg - resource
    * [-v]   - verbose
    * [-h]   - prints this message
    * </pre>
    *
    * <i>Check the policy of the resource named "R1"</i><br>
    * example: akenti RemoteCheckPolicy -F conf.txt -r "R1" 
    */
  int main(int, char**);
}


namespace RemoteResourceBrowse {
  /**
    * <big>RemoteResourceBrowse (akenti RRB)</big><br>
    * Use this program to browse a remote resource. 
    *
    * <pre>
    * -F arg   - akenti client config file
    * [-r arg] - resource
    * [-v]     - verbose
    * [-h]     - prints this message
    * </pre>
    *
    * <i>List top level resources.</i><br>
    * example: akenti RemoteResourceBrowse -F conf.txt 
    * <p>
    * <i>List immediate resources under R1/S1</i><br>
    * example: akenti RRB -F conf.txt -r R1/S1
    */
  int main(int, char**);
}

namespace RemoteCreateResource {
  /**
    * <big>RemoteCreateResource (akenti RCR)</big><br>
    *
    * Use this program to create a remote resource.
    * Root resources cannot be created remotely.
    * <pre>
    * -F arg  - akenti client config file
    * -r arg  - resource
    * [-v]    - verbose
    * [-h]    - prints this message
    * </pre>
    *
    * <i>Create a resource called "S2" under the resource called "R1"</i><br>
    * example: akenti CR -f conf.txt -r "R1/S2"
    */
  int main(int, char**);
}

namespace RemoteDeleteResource {
  /**
    * <big>RemoteDeleteResource (akenti RDR)</big><br>
    *
    * Use this program to delete a remote resource.
    * Root resources cannot be delete remotely.
    * <pre>
    * -F arg  - akenti client config file
    * -r arg  - resource
    * [-v]    - verbose
    * [-h]    - prints this message
    * </pre>
    *
    * <i>Delete a resource called "S2" under the resource called "R1"</i><br>
    * example: akenti DR -f conf.txt -r "R1/S2"
    */
  int main(int, char**);
}

namespace RemoteUploadPolicyCertificate {
  /**
    * <big>RemoteUploadPolCert (akenti RUP)</big><br>
    *
    * Use this program to remotely upload a policy certificate.
    *
    * <pre>
    * -F arg - akenti client config file
    * -p arg - policy certificate file
    * [-v]   - verbose
    * [-h]   - prints this message
    * </pre>
    *
    * <i>Upload the policy certificate called "polCert".
    * The policy certificate will indicate which resource
    * it modifies.</i><br>
    * example: akenti RUP -F conf.txt -p polCert
    */
  int main(int, char**);
}

namespace RemoteDeletePolicyCertificate {
  /**
    * <big>RemoteDeletePolCert (akenti RDP)</big><br>
    *
    * Use this program to remotely delete a policy certificate.
    *
    * <pre>
    * -F arg - akenti client config file
    * -r arg - resource
    * [-v]   - verbose
    * [-h]   - prints this message
    * </pre>
    *
    * <i>Delete the policy certificate located at R2 if there is one.</i>
    * example: akenti RDP -F conf.txt -r "R2" 
    */
  int main(int, char**);
}
 
// AKENTI CERT TOOLS
namespace CertGen {
  /** 
    * <big>CertGen (akenti CG)</big><br>
    *
    * Use this program to generate signed Policy, Use-Condition, and 
    * Attribute certificates. 
    *
    * <pre>
    * -k arg    - keyfile in p12 format
    * -p arg    - file where passphrase is stored
    * -i arg    - xml input file
    * [-o arg]  - friendly name to store file
    * [-d arg]  - number of days
    * [-v]      - verbose
    * [-h]      - prints this message
    * </pre>
    * 
    * <i>Sign the certificate called "xmlCertFile" (probably based on a
    * template generated with PrintAkentiCertTemplate) with my key and 
    * password</i><br>
    * example: akenti CertGen -k mykeyfile -p mypasswordfile -i xmlCertFile
    */
  int main(int, char**);
}

namespace PrintAkentiCertTemplate {
  /**
    * <big>PrintAkentiCertTemplate (akenti PT)</big><br>
    *
    * Use this program to print an akenti certificate template.
    * Edit the templates  for your own use.
    *
    * <pre>
    * [-R] - Root Policy certificate
    * [-P] - Policy certificate
    * [-U] - Use-Condition certificate
    * [-A] - Attribute certificate
    * [-o] - output file name
    * [-v] - verbos
    * [-h] - prints this message
    * </pre>
    *
    * <i>Print a template for a Root Policy Certificate.</i><br>
    * example: akenti PT -R
    */
  int main(int, char**);
}

namespace ConvertAkentiCert {
  /**
    * <big>ConvertAkentiCert (akenti CO)</big><br>
    *
    * Use this program to convert an akenti certificate from one format to another.
    * Currently we support two formats PEM and XML.
    *
    * <pre>
    * -a arg   - akenti certificate
    * [-i arg] - in format PEM or XML
    * [-o arg] - out format PEM or XML
    * [-v]     - verbos
    * [-h]     - prints this message
    * </pre>
    *
    * <i>Convert "mycertificate" from PEM to XML</i><br>
    * example: akenti ConvertAkentiCert -a mycertificate -i "PEM" -o "XML"
    */
  int main(int, char**);
}

namespace VerifyAkentiCert {
  /**
    * <big>VerifyAkentiCert (akenti VA)</big><br>
    *
    * Check 1: akenti certificate has not expired<br>
    * Check 2: akenti certificate's signature is valid (optional)<br>
    * Note: a check is made on the time validity of the signer's certificate if
    * one is supplied.
    *
    * <pre>
    * -a arg   - akenti certificate
    * [-i arg] - issuer's x509 certificate
    * [-v]     - verbos
    * [-h]     - prints this message
    * </pre>
    *
    * <i>Check to make sure "mycertificate" is good.</i><br>
    * example: akenti VerifyAkentiCert -a mycertificate 
    */
  int main(int, char**);
}

namespace PrettyPrintAkentiCert {
  /**
    * <big>PrettyPrintAkentiCert (akenti PP)</big><br>
    *
    * Use this program to pretty print an akenti certificate.
    *
    * <pre>
    * -a arg - akenti certificate
    * [-v]   - verbose
    * [-h]   - prints this message
    * </pre>
    *
    * <i>Print a beautiful human readable representation of a certificate.</i><br>
    * example: akenti PrettyPrintAkentiCert -a mycertificate 
    */
  int main(int, char**);
}
 
// X509 CERT TOOLS
namespace HashX509 {
  /**
    * <big>HashX509 (akenti HX)</big><br>
    *
    * Use this program to generate the hash of an X509 cert. 
    *
    * <pre>
    * -x arg - X509 certificate (in PEM format)
    * [-v]   - verbose
    * [-h]   - prints this message
    * </pre>
    *
    * <i>Create a hash of "myX509certificate".</i><br>
    * example: akenti HashX509 -x myX509certificate 
    */
  int main(int, char**);
}

namespace VerifyX509Cert {
  /**
    * <big>VerifyX509Cert (akenti VX)</big><br>
    *
    * Purpose: Use this program to verify an x509 cert.<br>
    * Check 1: time validity<br>
    * Check 2: signature (optional)
    *
    * <pre>
    * -x arg   - X509 certificate
    * [-i arg] - ca's X509 cert
    * [-v]     - verbos
    * [-h]     - prints this message
    * </pre>
    *
    * <i>Make sure that this myX509certificate hasn't expired</i><br>
    * example: akenti VerifyX509Cert -x myX509certificate 
    */
  int main(int, char**);
}
 
// OTHER
namespace FindUC {
  /**
    * <big>FindUC (akenti FU)</big><br>
    *
    * Use this program to locate Use-Condition certificates.
    *
    * <pre>
    * -r arg - resource
    * -u arg - location in a url format
    * [-v]   - verbose
    * [-h]   - prints this message
    * </pre>
    *
    * <i>Find a Use-Condition certificate for "R1/S1" at "localhost/dir"</i><br>
    * example: akenti FindUC -r R1/S1 -u http://localhost/dir 
    */
  int main(int, char**);
}

namespace PrintConfigTemplate {
  /**
    * <big>PrintConfigTemplate (akenti PC)</big><br>
    *
    * Use this programe to generate a configuration file template.
    *
    * <pre>
    * [-E] - engine/server config file
    * [-C] - remote client config file
    * [-o] - output file name
    * [-v] - verbose
    * [-h] - prints this message
    * </pre>
    *
    * <i>Generate a remote client config file</i>
    * example: akenti PC -C
    */
  int main(int, char**);
}
