#include <sstream>
#include <iostream>
#include <string>
#include <unistd.h>
#include "DeleteResourceRequest.hpp"
#include "DeleteResourceResponse.hpp"
#include "ProtocolHandler.hpp"
#include "AkentiInit.hpp"
#include "Exception.hpp"
#include "Error.hpp"

using namespace Akenti;
using namespace std;

/**
  * <pre>
  * <b>DeleteResource</b>
  *   Use this program to create a resource.
  * </pre>
  */
namespace DeleteResource {

void printPurpose() {
  cerr << "Use this program to create a resource." << endl 
       << endl;
}

void printUsage () {
  cerr << "Usage: DeleteResource args" << endl
       << "  -f arg          - akenti engine config file" << endl
       << "  -r arg          - resource" << endl
       << "  [-v]            - verbose" << endl
       << "  [-h]            - prints this message" << endl;
}

int 
main(int argc, char** argv) {
  if (argc < 2) {
    printPurpose();
    printUsage();
    exit(2);
  }

  string confFileName;
  string resource;
  bool verbose = false;
  int opt;

  while ((opt = getopt(argc,argv,"f:r:vh")) != EOF) {
    switch(opt){
      case 'f':
        confFileName = optarg;
        break;
      case 'r':
        resource = optarg;
        break;
      case 'v':
        verbose = true;
        break;
      case 'h':
      default:
        printUsage();
        exit(2);
    }
  }

  try {
    if (verbose) {
      cout  << "Initializing Akenti engine ..." << endl;
    }

    string status;
  
    if (!AkentiInit::init(confFileName, status)) {
      cerr << status << endl;
      exit(2);
    }

    if (verbose) {
      cout  << status << endl;
    }

    if (resource == "") {
      cerr << "Must provide a resource" << endl;
      exit(2);
    }
 
    DeleteResourceRequest req;
    DeleteResourceResponse resp;
 
    req.setID(1);
    req.setResource(resource);
    ProtocolHandler::getInstance(ProtocolHandler::ENGINE).handle(req, resp);
   
    AkentiMessage mesg = resp.getAkentiMessage();

    cout << mesg.toString() << endl;

    exit(mesg.getCode() >= 200);
  } catch(Exception& ex) {
    cerr << "Exception:" << ex << endl;
    exit(2);
  } catch(Error& err) {
    cerr << "ERROR:Report to akenti team:" << err << endl;
    exit(3);
  } 
}

}
