#include <iostream>
#include <string>
#include <unistd.h>
#include "AkentiCertificate.hpp"
#include "File.hpp"
#include "Provider.hpp"
#include "OpenSSLProviderImpl.hpp"
#include "XMLUtil.hpp"
#include "Exception.hpp"
#include "Error.hpp"

using namespace Akenti;
using namespace std;

/**
  * <pre>
  * <b>PrettyPrintAkentiCert:</b>
  *   Use this program to pretty print a PEM encoded akenti certificate.
  *
  * </pre>
  */
namespace PrettyPrintAkentiCert {

void printPurpose() {
  cerr << "Use this program to pretty print an akenti certificate." << endl
       << endl;
}

void printUsage() {
  cerr << "Usage: PrettyPrintAkentiCert args" << endl
       << "  -a arg      - akenti certificate" << endl
       << "  [-v]        - verbose" << endl
       << "  [-h]        - print this message" << endl;
}

int
main (int argc, char *argv[]) {
  string akentiCertFileName;
  bool verbose = false;
  int opt;

  if (argc < 2) {
    printPurpose();
    printUsage();
    exit(2);
  }

  while ((opt = getopt(argc, argv, "a:vh")) != EOF) {
    switch(opt){
      case 'a':
        akentiCertFileName = optarg;
        break;
      case 'v':
        verbose = true;
        break;
      case 'h':
      default:
        printUsage();
        exit(2);
    }
  }

  try {
    if (verbose) {
      cout << "Initializing XML library" << endl;
    }

    XMLUtil::init();

    if (verbose) {
      cout << "Setting security provider ..." << endl;
    }

    Provider::setProvider(new OpenSSLProviderImpl);

    if (verbose) {
      cout << "Reading akenti certificate " << akentiCertFileName << endl;
    }

    if (!File(akentiCertFileName).isFile()) {
      cerr << "Can't open akenti certificate " << akentiCertFileName << endl;
      exit(2);
    }

    AkentiCertificate cert = AkentiCertificate::initFromFile(akentiCertFileName);

    cout << cert->toText() << endl;
    exit(0);
  } catch (Exception& ex) {
    cerr << "caught Exception " << ex.getMessage() << endl;
    exit(2);
  } catch (Error& er) {
    cerr << "caught error " << er.getMessage() <<endl;
    exit(3);
  }
}

}
