#include <iostream>
#include <fstream>
#include <string>
#include <unistd.h>
#include "Exception.hpp"
#include "Error.hpp"
#include "XMLUtil.hpp"

using namespace std;
using namespace Akenti;

/**
  * <pre>
  * <b>PrintConfigTemplate</b>
  *   Use this program to print akenti config templates.
  * </pre>
  */

namespace PrintConfigTemplate {

void 
printPurpose() {
  cerr << "Use this program to print akenti config files." << endl
       << endl;
}

void 
printUsage() {
  cerr << "Usage: PrintConfigTemplate args" << endl
       << "  [-E]        - engine/server config file" << endl
       << "  [-C]        - remote client config file" << endl
       << "  [-o]        - output file name" << endl
       << "  [-v]        - verbose"<< endl 
       << "  [-h]        - prints this message "<< endl; 
}

int
main(int argc, char *argv[]) {
  if (argc < 2) {
    printPurpose();
    printUsage();
    exit(2);
  }

  string outputCertFileName;
  bool verbose = false;
  bool client = false;
  bool server = false;
  int opt;

  while ((opt = getopt(argc, argv, "o:CEvh")) != EOF) {
    switch(opt){
      case 'C':
        client = true;
        break;
      case 'E':
        server = true;
        break;
      case 'o':
        outputCertFileName = optarg;
        break;
      case 'v':
        verbose = true;
        break;
      case 'h':
      default:
        printUsage();
        exit(2);
    }
  }

  try {
    // TODO
    if (!((client || server) && !(client && server))) {
      cerr << "Must specify either a client or a server(engine) option" << endl;
      exit(2);
    }

    ostream* ptr;

    if (outputCertFileName.length()) {
      ptr = new ofstream(outputCertFileName.c_str());
    } else {
      ptr = &cout;
    }
   
    ostream& os = *ptr;

    if (client) {
      os << "#############################################################\n"
         << "#               BEGIN CLIENT'S CREDENTIALS                  #\n"
         << "#    SSLMode          [on, off]                             #\n"
         << "#    AkentiHost       default localhost                     #\n"
         << "#    AkentiPort       default secure port 8443              #\n"
         << "#                     default unsecure port 8444            #\n"
         << "#    ClientCertFile   client's certificate pathanme         #\n"
         << "#    ClientKeyFile    client's private key pathname         #\n"
         << "#    CertificateAuthorityPath  dirpath to trusted CAs       #\n"
         << "#    CertificateAuthorityFile  file containing trusted CAs  #\n"
         << "#                                                           #\n"
         << "SSLMode " << "on" << "\n"
         << "ClientCertFile " << "\n"
         << "ClientKeyFile  " << "\n"
         << "CertificateAuthorityPath " << "\n"
         << "CertificateAuthorityFile " << "\n"
         << "#                                                           #\n"
         << "#               END CLIENT'S CREDENTIALS                    #\n"
         << "#############################################################\n";
    } else {
      os << "#############################################################\n"
         << "#                                                           #\n"
         << "# Akenti server (engine) may be providing access control to #\n"
         << "# several independent resources.                            #\n"
         << "#                                                           #\n"
         << "# For each top level resource (root), we must specify an    #\n"
         << "# absolute path.                                            #\n"
         << "#                                                           #\n"
         << "RootResourceName " << "ROOT1 " << "/home/...../path1" << "\n"
         << "RootResourceName " << "ROOT2 " << "/home/...../path2" << "\n"
         << "#############################################################\n"
         << "#                                                           #\n"
         << "# The name of policy files defaults to htauthority.         #\n"
         << "#                                                           #\n"
         << "PolicyFileName "<< '\n'
         << "#                                                           #\n"
         << "#############################################################\n"
         << "#                                                           #\n"
         << "# The name of hint files (used by Java GUI cert generators) #\n"
         << "# defaults to resattrs.xml                                  #\n"
         << "#                                                           #\n"
         << "ResAttrFileName "<< '\n'
         << "#############################################################\n"
         << "#                                                           #\n"
       	 << "# The encoding type of akenti certificates (XML or PEM).    #\n"
         << "# Leave blank to support reading both types.                #\n"
         << "#                                                           #\n"
         << "AK_CERT_ENC_TYPE " << '\n'
         << "# \n"
         << "#############################################################\n"
         << "#              BEGIN AUTH SERVER INFO                       #\n"
         << "#                                                           #\n"
         << "#    SSLMode          [on, off]                             #\n"
         << "#    AkentiPort       default secure port 8443              #\n"
         << "#                     default unsecure port 8444            #\n"
         << "#    ServerCertFile   server's certificate pathanme         #\n"
         << "#    ServerKeyFile    server's private key pathname         #\n"
         << "#                                                           #\n"
         << "SSLMode " << "on" << "\n"
         << "ServerCertFile " << "\n"
         << "ServerKeyFile  " << "\n"
         << "AkentiPort" << "\n"
         << "#                                                           #\n"
         << "####################   Signing     ##########################\n"
         << "#                                                           #\n"
         << "#     SignCerts [on, off] Signing capability/cached certs.  #\n"
         << "#                                                           #\n"
         << "SignCerts on \n"
         << "#                                                           #\n"
         << "#              END AUTH SERVER INFO                         #\n"
	 << "#############################################################\n"
         << "#############################################################\n"
         << "#              BEGIN CACHE CONFIG                           #\n"
         << "#                                                           #\n"
         << "# Caching Parameters:                                       #\n"
         << "#                                                           #\n"
         << "#    Caching   [on, off]                                    #\n"
         << "#    CacheDir  the name of the caching directory            #\n"
         << "#                                                           #\n"
         << "Caching " << "on" << "\n"
         << "CacheDir " << "/home/u3/.../path3" << "\n"
         << "#                                                           #\n"
         << "#              END CACHE CONFIG                             #\n"
         << "#############################################################\n"
         << "#############################################################\n"
         << "#              BEGIN LOGGING CONFIG                         #\n"
         << "#                                                           #\n"
         << "# Type of logging desired                                   #\n"
         << "# Logging  [off, file, server, stdout, stderr]              #\n"
         << "#                                                           #\n"
         << "# Setting the logging level: only logs with a               #\n" 
         << "#                                                           #\n"
         << "# level <= LogLevel will be logged.                         #\n"
         << "#    LogLevel [1, 2, 3, 4, 5]                               #\n"
         << "#                                                           #\n"
         << "# Logging to a file:                                        #\n"
         << "#                                                           #\n"
         << "#    TempLogDir  temporary storage                          #\n"
         << "#    MonitorLogFile permanent storage                       #\n"
         << "#                                                           #\n"
         << "# Logging to a server                                       #\n"
         << "#                                                           #\n"
         << "#    MonitorServer   server's hostname                      #\n"
         << "#    MonitorPort     server's port                          #\n"
         << "#                                                           #\n"
         << "Logging " << "file" << "\n"
         << "LogLevel " <<  2 << "\n"
         << "# File Logging Mechanism                                    #\n"
         << "TempLogDir " << "/tmp" << "\n"
         << "MonitorLogFile " << "./aklogs" << "\n"
         << "# Server Logging Mechanism                                  #\n"
         << "MonitorServer  " << "\n"
         << "MonitorPort " << "\n"
         << "#                                                           #\n"
         << "#             END LOGGING CONFIG                            #\n"
         << "#############################################################\n";
    }

    if (outputCertFileName.length()) {
      delete(ptr);
    }

    exit(0);
  } catch (Exception& ex) {
    cerr << "Exception:" << ex.getMessage() << endl;
    exit(2);
  } catch (Error& err) {
    cerr << "Error:Report to Akenti team:" << err.getMessage() << endl;
    exit(3);
  }
}

}
