#include <sstream>
#include <iostream>
#include <string>
#include <unistd.h>
#include "Provider.hpp"
#include "OpenSSLProviderImpl.hpp"
#include "ResourceBrowseRequest.hpp"
#include "ResourceBrowseResponse.hpp"
#include "ProtocolHandler.hpp"
#include "AkentiInit.hpp"
#include "XMLUtil.hpp"

using namespace Akenti;
using namespace std;

/**
  * <pre>
  * <b>ResourceBrowse</b>
  *   Use this program to browse a resource.
  * </pre>
  */
namespace ResourceBrowse {

void printPurpose() {
  cerr << "Use this program to browse a resource." << endl 
       << endl;
}

void printUsage () {
  cerr << "Usage: ResourceBrowse args" << endl
       << "  -f arg          - akenti engine config file" << endl
       << "  [-r arg]        - resource" << endl
       << "  [-v]            - verbose" << endl
       << "  [-h]            - prints this message" << endl;
}

int 
main(int argc, char** argv) {
  if (argc < 2) {
    printPurpose();
    printUsage();
    exit(2);
  }

  string confFileName;
  string resource;
  bool verbose = false;
  int opt;

  while ((opt = getopt(argc,argv,"f:r:vh")) != EOF) {
    switch(opt){
      case 'f':
        confFileName = optarg;
        break;
      case 'r':
        resource = optarg;
        break;
      case 'v':
        verbose = true;
        break;
      case 'h':
      default:
        printUsage();
        exit(2);
    }
  }

  try {
    if (verbose) {
      cout  << "Initiizing XML library ... " << endl;
    }

    XMLUtil::init();

    if (verbose) {
      cout  << "Installing security provider ..." << endl;
    }
    
    Provider po = Provider(new OpenSSLProviderImpl);
 
    po->loadSignatureAlgorithms();
    po->seedRandomGenerator("WE GOT TO SEED THE RANDOM GENERATOR");
    Provider::setProvider(po);

    if (verbose) {
      cout  << "Initializing akenti engine ..." << endl;
    }

    string status;

    if (!AkentiInit::init(confFileName, status)) {
      cerr  << status << endl;
      exit(2);
    }

    if (verbose) {
      cout << status  << endl;
    }

    ResourceBrowseRequest req;
    ResourceBrowseResponse resp;

    req.setID(1);
   
    if (resource.length()) {
      req.setResource(resource);
    }

    ProtocolHandler::getInstance(ProtocolHandler::ENGINE).handle(req, resp);

    AkentiMessage mesg  = resp.getAkentiMessage();

    cout << mesg.toString() << endl;

    vector<string> resources = resp.getResources();
   
    for (int i = 0; i < resources.size(); ++i) {
      cout << resources[i] << endl;
    } 

    exit(mesg.getCode() >= 200);
  } catch(Exception& ex) {
    cerr << "Exception:" << ex << endl;
    exit(2);
  } catch(Error& err) {
    cerr << "ERROR:Report to akenti team:" << err << endl;
    exit(3);
  } 
}

}
