#!/bin/sh

# Generates the certificates in exampleResourceTree using the 
# Java cert generator program

if test "${AKENTI_HOME+set}" != set; then
  echo "\${AKENTI_HOME} is not set."
  AKENTI_HOME=`dirname $0`/..
  echo "Using AKENTI_HOME=\"${AKENTI_HOME}\" for this run."
fi


# Generate the root .htauthority file from TEST/rootPolicyCert.xml, signed by
# AkTest cert.

ResourceTree="../../exampleResourceTree"
CLASSP="$AKENTI_HOME/classes/akcore.jar:$AKENTI_HOME/3rdparty/xerces.jar:$AKENTI_HOME/3rdparty/xercesSamples.jar:$AKENTI_HOME/classes/aktools.jar"

echo CLASSP: $CLASSP
echo
echo "$0: Removing any previously generated certificates..."
rm -f $ResourceTree/certs/*.0
rm -f $ResourceTree/certs/*.1
rm -f $ResourceTree/TEST/*.0
rm -f $ResourceTree/TEST/test1/*.0
rm -f $ResourceTree/TEST/test2/*.0

echo "$0: Making links in idCerts directory"
ln -s shICert.9cd44578.0 $ResourceTree/idCerts/shICert.pem
ln -s shIICert.abcd95fd.0 $ResourceTree/idCerts/shIICert.pem
ln -s userICert.fa924567.0 $ResourceTree/idCerts/userICert.pem
ln -s userIICert.3a6edc24.0 $ResourceTree/idCerts/userIICert.pem

echo "$0: Generating TEST/htauthority from TEST/rootPolicy.xml..."
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti CG -k $ResourceTree/idCerts/shI.p12 -p testing -o $ResourceTree/TEST/htauthority -i $ResourceTree/TEST/rootPolicy.xml
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

# Generate a use Condition for the root from $ResourceTree/TEST/uc.xml and 
# store it in $ResourceTree/certs. Sign it by Stake Holder I

echo
echo "$0: Generating certs/TESTuc from TEST/uc.xml..."
rm -f $ResourceTree/certs/TESTuc

CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti CG -k $ResourceTree/idCerts/shI.p12 -p testing -o $ResourceTree/certs/TESTuc -i $ResourceTree/TEST/uc.xml
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

# Generate a htauthority for $ResourceTree/TEST/test1 from 
# $ResourceTree/TEST/test1/policy.xml signed by  StakeHolder I
echo
echo "$0: Generating TEST/test1/htauthority from TEST/test1/policy.xml..."
rm -f $ResourceTree/TEST/test1/htauthority

CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti CG -k $ResourceTree/idCerts/shI.p12 -p testing -o $ResourceTree/TEST/test1/htauthority -i $ResourceTree/TEST/test1/policy.xml
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

# Generate the uc for $ResourceTree/TEST/test1 signed by StakeHolder I and 
# stored in $ResourceTree/certs
echo
echo "$0: Generating certs/test1uc from TEST/test1/uc.xml..."
rm -f  $ResourceTree/certs/test1uc 
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti CG -k $ResourceTree/idCerts/shI.p12 -p testing -o $ResourceTree/certs/test1uc -i $ResourceTree/TEST/test1/uc.xml
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

# Generate the policy for $ResourceTree/TEST/test2 signed by StakeHolder I 
# from $ResourceTree/TEST/test2/policy.xml and stored in 
# $ResourceTree/TEST/test2/htauthority
echo
echo "$0: Generating TEST/test2/htauthority from TEST/test2/policy.xml..."
rm -f $ResourceTree/TEST/test2/htauthority
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti CG -k $ResourceTree/idCerts/shI.p12 -p testing -o $ResourceTree/TEST/test2/htauthority -i $ResourceTree/TEST/test2/policy.xml
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

# Generate a Usecondition for $ResourceTree/TEST/test2 from 
# $ResourceTree/TEST/test2/uc1.xml signed by 
# Stake Holder I and stored in $ResourceTree/certs
echo
echo "$0: Generating certs/test2uc from TEST/test2/uc1.xml..."
rm -f $ResourceTree/certs/test2uc
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti CG -k $ResourceTree/idCerts/shI.p12 -p testing -o $ResourceTree/certs/test2uc1 -i $ResourceTree/TEST/test2/uc1.xml
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

# Generate a Usecondition for $ResourceTree/TEST/test2 from 
# $ResourceTree/TEST/test2/uc2.xml signed by StakeHolder II
# and stored in $ResourceTree/certs 
echo
echo "$0: Generating certs/test2uc2 from TEST/test2/uc2.xml..."
rm -f $ResourceTree/certs/test2uc2
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti CG -k $ResourceTree/idCerts/shII.p12 -p testing -o $ResourceTree/certs/test2uc2 -i $ResourceTree/TEST/test2/uc2.xml
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

# Generate an attribute certficate granting User I the role of tester
# signed by Stake Holder II.
echo
echo "$0: Generating certs/atRoleTester from certs/atRoleTester.xml..."
rm -f $ResourceTree/certs/atRoleTester
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti CG -k $ResourceTree/idCerts/shII.p12 -p testing -o $ResourceTree/certs/atRoleTester -i $ResourceTree/certs/atRoleTester.xml
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

# Generate an attribute certficate granting User II membership in group
# Developers signed by Stake Holder I.
echo
echo "$0: Generating certs/atGroupDev from certs/atGroupDev.xml..."
rm -f $ResourceTree/certs/atGroupDev
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti CG -k $ResourceTree/idCerts/shI.p12 -p testing -o $ResourceTree/certs/atGroupDev -i $ResourceTree/certs/atGroupDev.xml
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

# Verify all the certs
echo
echo "Verifying TEST/htauthority..."
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti VA -a $ResourceTree/TEST/htauthority -i $ResourceTree/idCerts/shICert.pem
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

echo
echo "Verifying certs/TESTuc..."
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti VA -a $ResourceTree/certs/TESTuc.4bd93b03.0 -i $ResourceTree/idCerts/shICert.pem
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

echo
echo "Verifying TEST/test1/htauthority..."
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti VA -a $ResourceTree/TEST/test1/htauthority -i $ResourceTree/idCerts/shICert.pem
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

echo
echo "Verifying certs/test1uc..."
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti VA -a $ResourceTree/certs/test1uc.efa6416b.0 -i $ResourceTree/idCerts/shICert.pem
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

echo
echo " Verifying TEST/test2/htauthority..."
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti VA -a $ResourceTree/TEST/test2/htauthority -i $ResourceTree/idCerts/shICert.pem
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

echo
echo "Verifying certs/test2uc1..."
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti VA -a $ResourceTree/certs/test2uc1.1ce7e998.0 -i $ResourceTree/idCerts/shICert.pem
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

echo
echo "Verifying certs/test2uc2..."
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti VA -a  $ResourceTree/certs/test2uc2.1ce7e998.0 -i $ResourceTree/idCerts/shIICert.pem
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

echo
echo "Verifying certs/atRoleTester..."
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti VA -a $ResourceTree/certs/atRoleTester.439cda5d.0 -i $ResourceTree/idCerts/shIICert.pem
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi

echo
echo "Verifying certs/atGroupDev..."
CLASSPATH="" java -classpath $CLASSP lbl.akenti.tools.Akenti VA -a $ResourceTree/certs/atGroupDev.d4759238.0 -i $ResourceTree/idCerts/shICert.pem
ret_val=$?
if [ ! "${ret_val}" = "0" ]; then exit ${ret_val}; fi
