#ifndef AK_PRIVATE_KEY_IMPL_HPP
#define AK_PRIVATE_KEY_IMPL_HPP

#include <string>

using std::string;

namespace Akenti {

/**
  * This abstract class defines part of the interface for PrivateKey
  * Implementation objects.
  *
  * @see ref_ptr
  * @see PrivateKeyImpl
  * @see KeyPair
  * @see KeyPair#getPrivateKey()
  * @see KeyFactory
  * @see KeyFactoryImpl#getKeyEncoded(const string&, const PrivateKey&)
  * @see KeyFactoryImpl#initPrivateKey(const string&, const string&, 
  *                                    const string&)
  * @see KeyFactoryImpl#generateRSAKeyPair(int, unsigned long)
  * @see KeyFactoryImpl#generateDSAKeyPair(int, const string&)
  * @see Signature
  * @see SignatureImpl#initSign(const PrivateKey&)
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai 
  * @author Abdelilah Essiari 
  */

class PrivateKeyImpl {

public:

  /**
    * Deletes this object. 
    */
  virtual ~PrivateKeyImpl() {
  }
  
  /**
    * Returns the standard algorithm name for this key. For
    * example, "DSA" would indicate that this key is a DSA key.
    *
    * @return the name of the algorithm associated with this key.
    */
  virtual string getAlgorithm() const = 0;

  /** 
    * Returns a string representation of PrivateKeyImpl which is used 
    * for debugging purposes.
    *
    * @return debugging info
    */
  virtual string paramString() const = 0;

protected:

  /**
    * Default Constructor.
    * Typically a <i>KeyFactory</i> is used to create an instance of
    * a subclass of this class. This object is then wrapped in a <i>
    * PrivateKey</i>.
    *
    * @see PrivateKey
    * @see KeyFactory
    * @see KeyFactoryImpl#initPrivateKey(const string&, 
    *                                    const string&, 
    *                                    const string&)
    * @see KeyFactoryImpl#generateRSAKeyPair(int, unsigned long)
    * @see KeyFactoryImpl#generateDSAKeyPair(int, const string&)
    */
  PrivateKeyImpl() {
  }

};

} // end of namespace Akenti

#endif
