#ifndef AK_PUBLIC_KEY_IMPL_HPP
#define AK_PUBLIC_KEY_IMPL_HPP
#include <string>

using std::string;

namespace Akenti {

/**
  * This abstract class mainly serves to group all public  
  * key objects.
  *
  * @see KeyPair
  * @see KeyPair#getPublicKey()
  * @see KeyFactory
  * @see KeyFactoryImpl#getKeyEncoded(const string&, const PublicKey&)
  * @see KeyFactoryImpl#initPublicKey(const string&, const string&, 
  *   const string&)
  * @see KeyFactoryImpl#generateRSAKeyPair(int, unsigned long)
  * @see KeyFactoryImpl#generateDSAKeyPair(int, const string&)
  * @see Signature
  * @see SignatureImpl#initVerify(const PublicKey&)
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai 
  * @author Abdelilah Essiari
  */

class PublicKeyImpl {

public:

  virtual ~PublicKeyImpl() {
  }

  /**
    * Returns the standard algorithm name for this key. For
    * example, "DSA" would indicate that this key is a DSA key.
    *
    * @return the name of the algorithm associated with this key.
    */
  virtual string getAlgorithm() const = 0;

  /**
    * Returns a string representation of this key for debugging
    * purposes.
    *
    * @return debugging info
    */
  virtual string paramString() const = 0;

protected:

  /**
    * Constructor.
    */
  PublicKeyImpl() {
  }

};

} // end of namespace Akenti

#endif
